@@ -3,7 +3,7 @@
  *  flatapi.cpp -	This file contains an api usable by non-C++
  *			environments
  *
- * $Id: flatapi.cpp 3226 2014-05-02 03:01:35Z greg.hellings $
+ * $Id: flatapi.cpp 3275 2014-12-03 05:56:54Z greg.hellings $
  *
  * Copyright 2002-2014 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -70,7 +70,7 @@ void clearStringArray(const char ***stringArray) {
 }
 
 
-void clearModInfo(org_crosswire_sword_ModInfo **modInfo) {
+void clearModInfoArray(org_crosswire_sword_ModInfo **modInfo) {
 	if (*modInfo) {
 		for (int i = 0; true; ++i) {
 			if ((*modInfo)[i].name) {
@@ -221,7 +221,7 @@ public:
 	}
 
 	void clearModInfo() {
-		::clearModInfo(&modInfo);
+		clearModInfoArray(&modInfo);
 	}
 
 	~HandleSWMgr() {
@@ -289,7 +289,7 @@ public:
 	}
 
 	void clearModInfo() {
-		::clearModInfo(&modInfo);
+		clearModInfoArray(&modInfo);
 	}
 };
 
