@@ -3,7 +3,7 @@
  *  versekey.cpp -	code for class 'VerseKey'- a standard Biblical
  *			verse key
  *
- * $Id: versekey.cpp 2893 2013-07-16 03:07:02Z scribe $
+ * $Id: versekey.cpp 3281 2014-12-03 06:07:22Z greg.hellings $
  *
  * Copyright 1998-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -157,7 +157,9 @@ void VerseKey::positionFrom(const SWKey &ikey) {
 	}
 	else {
 		SWKey::positionFrom(*fromKey);
-		parse();
+// extraneous parse which inadvertently clears error flag
+// SWKey::positionFrom already calls copyFrom which calls setText, which VerseKey::setText already calls parse()
+//		parse();
 	}
 
  	// should we always perform bounds checks?  Tried but seems to cause infinite recursion
@@ -212,7 +214,9 @@ void VerseKey::copyFrom(const SWKey &ikey) {
 	}
 	else {
 		SWKey::copyFrom(*fromKey);
-		parse();
+// extraneous parse which inadvertently clears error flag
+// SWKey::copyFrom already calls setText, which VerseKey::setText already calls parse()
+//		parse();
 	}
 }
 
