@@ -2,7 +2,7 @@
  *
  *  osis2mod.cpp -	Utility to import a module in OSIS format
  *
- * $Id: osis2mod.cpp 3177 2014-04-17 04:24:37Z greg.hellings $
+ * $Id: osis2mod.cpp 3314 2014-12-24 06:10:01Z greg.hellings $
  *
  * Copyright 2003-2014 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -351,7 +351,7 @@ void prepareSWVerseKey(SWBuf &buf) {
  * Determine whether a verse as given is valid for the versification.
  * This is done by comparing the before and after of normalization.
  */
-bool isValidRef(const char *buf) {
+bool isValidRef(const char *buf, const char *caller) {
 	// Create a VerseKey that does not do auto normalization
 	// Note: need to turn on headings so that a heading does not get normalized anyway
 	// And set it to the reference under question
@@ -382,7 +382,7 @@ bool isValidRef(const char *buf) {
 	// If we have gotten here the reference is not in the selected versification.
 	// cout << "INFO(V11N): " << before << " is not in the " << currentVerse.getVersificationSystem() << " versification." << endl;
 	if (debug & DEBUG_REV11N) {
-		cout << "DEBUG(V11N): " << before << " normalizes to "  << after << endl;
+		cout << "DEBUG(V11N)[" << caller << "]: " << before << " normalizes to "  << after << endl;
 	}
 
 	return false;
@@ -465,7 +465,7 @@ void makeValidRef(VerseKey &key) {
 void writeEntry(SWBuf &text, bool force = false) {
 	char keyOsisID[255];
 
-	static const char* revision = "<milestone type=\"x-importer\" subType=\"x-osis2mod\" n=\"$Rev: 3177 $\"/>";
+	static const char* revision = "<milestone type=\"x-importer\" subType=\"x-osis2mod\" n=\"$Rev: 3314 $\"/>";
 	static bool firstOT = true;
 	static bool firstNT = true;
 
@@ -494,7 +494,7 @@ void writeEntry(SWBuf &text, bool force = false) {
 	// If we have seen a verse and the supplied one is different then we output the collected one.
 	if (*activeOsisID && strcmp(activeOsisID, keyOsisID)) {
 
-		if (!isValidRef(lastKey)) {
+		if (!isValidRef(lastKey, "writeEntry")) {
 			makeValidRef(lastKey);
 		}
 
@@ -563,7 +563,7 @@ void writeEntry(SWBuf &text, bool force = false) {
 void linkToEntry(VerseKey &linkKey, VerseKey &dest) {
 
 	// Only link verses that are in the versification.
-	if (!isValidRef(linkKey)) {
+	if (!isValidRef(linkKey, "linkToEntry")) {
 		return;
 	}
 
@@ -802,10 +802,13 @@ bool handleToken(SWBuf &text, XMLTag token) {
 					// At that point we will output links.
 					// This can be done by incrementing, which will produce an error
 					// if there is only one verse.
-					verseKeys.setPosition(TOP);
-					verseKeys.increment(1);
-					if (!verseKeys.popError()) {
-						linkedVerses.push_back(verseKeys);
+					if (memberKeyCount > 1) {
+						verseKeys.setPosition(TOP);
+						verseKeys.increment(1);
+						if (!verseKeys.popError()) {
+							cout << "DEBUG(LINK): " << currentVerse.getOSISRef() << endl;
+							linkedVerses.push_back(verseKeys);
+						}
 					}
 				}
 				else {
@@ -852,6 +855,36 @@ bool handleToken(SWBuf &text, XMLTag token) {
 
 		// Now consider everything else.
 
+		// "majorSection" is code for the Book 1-5 of Psalms
+		if (tokenName == "div" && typeAttr == "majorSection") {
+			if (inBookIntro) {
+				if (debug & DEBUG_TITLE) {
+					cout << "DEBUG(TITLE): " << currentOsisID << ": BOOK INTRO "<< text << endl;
+				}
+				writeEntry(text);
+			}
+
+			if (debug & DEBUG_OTHER) {
+				cout << "DEBUG(FOUND): majorSection found " << currentVerse.getOSISRef() << endl;
+			}
+
+			strcpy(currentOsisID, currentVerse.getOSISRef());
+
+			inChapter       = false;
+			inVerse         = false;
+			inPreVerse      = false;
+			inBookIntro     = false;
+			inChapterIntro  = true;
+
+			if (debug & DEBUG_TITLE) {
+				cout << "DEBUG(TITLE): " << currentOsisID << ": Looking for chapter introduction" << endl;
+			}
+
+			verseDepth      = 0;
+
+			return false;
+		}
+
 		// Handle WOC quotes.
 		// Note this requires transformBSP to make them into milestones
 		// Otherwise have to do it here
@@ -1272,8 +1305,8 @@ void writeLinks()
 
 		while (!verseKeys.popError()) {
 			linkKey = verseKeys.getElement();
-			verseKeys.increment(1);
 			linkToEntry(linkKey, destKey);
+			verseKeys.increment(1);
 		}
 	}
 }
@@ -1552,7 +1585,7 @@ void processOSIS(istream& infile) {
 
 int main(int argc, char **argv) {
 
-	fprintf(stderr, "You are running osis2mod: $Rev: 3177 $\n");
+	fprintf(stderr, "You are running osis2mod: $Rev: 3314 $\n");
 	
 	if (argc > 1) {
 		for (int i = 1; i < argc; i++) {
